#
# Copyright (c) 2020-2024 Esrille Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, see <http://www.gnu.org/licenses/>.

import gettext
import os

from gi.repository import GLib, Gio


HIRAGANA_IME_KEY = 'org.freedesktop.ibus.engine.hiragana'


def get_name():
    return 'furiganapad'


def get_version():
    return '0.7.1'


def get_prefix():
    return '/usr'


def get_datadir():
    return '/usr/share/furiganapad'


def get_user_datadir():
    return os.path.join(GLib.get_user_data_dir(), 'furiganapad')


def get_localedir():
    return '/usr/share/locale'


def get_domain():
    source = Gio.SettingsSchemaSource.get_default()
    if source.lookup(HIRAGANA_IME_KEY, True):
        config = Gio.Settings.new(HIRAGANA_IME_KEY)
        path = config.get_string('dictionary')
        path = os.path.basename(path)
        if path in ('restrained.1.dic', 'restrained.2.dic', 'restrained.3.dic',
                    'restrained.4.dic', 'restrained.5.dic', 'restrained.6.dic'):
            return get_name() + '.school'
    return get_name()


def _(text):
    return gettext.dgettext(get_domain(), text)
